@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.40';
+  $CPAN::Perl::Releases::VERSION = '0.44';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -240,6 +240,14 @@ our $data =
     "tar.bz2" => "D/DR/DROLSKY/perl-5.15.6.tar.bz2",
     "tar.gz" => "D/DR/DROLSKY/perl-5.15.6.tar.gz",
   },
+  "5.15.7" => {
+    "tar.bz2" => "B/BI/BINGOS/perl-5.15.7.tar.bz2",
+    "tar.gz" => "B/BI/BINGOS/perl-5.15.7.tar.gz",
+  },
+  "5.15.8" => {
+    "tar.bz2" => "C/CO/CORION/perl-5.15.8.tar.bz2",
+    "tar.gz" => "C/CO/CORION/perl-5.15.8.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -348,7 +356,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.40
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -404,7 +412,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chris Williams.
+This software is copyright (c) 2012 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
